Installation | Chart.js
Description: Open source HTML5 Charts for your website

## # npm

(opens new window)
(opens new window)

    npm install chart.js

## # CDN

### # CDNJS

(opens new window)

Chart.js built files are available on CDNJS
(opens new window):

https://cdnjs.com/libraries/Chart.js
(opens new window)

### # jsDelivr

(opens new window)
(opens new window)

Chart.js built files are also available through jsDelivr
(opens new window):

https://www.jsdelivr.com/package/npm/chart.js?path=dist
(opens new window)

## # Github

(opens new window)

You can download the latest version of Chart.js on GitHub
(opens new window).

If you download or clone the repository, you must build Chart.js to generate the dist files. Chart.js no longer comes with prebuilt release versions, so an alternative option to downloading the repo is strongly advised.